<?php

use Jcupitt\Vips\Image;
use Jcupitt\Vips\Size;

require __DIR__ . '/vendor/autoload.php';

const VIPS_META_ORIENTATION = 'orientation';

foreach (['Landscape', 'Portrait'] as $orientation) {
    foreach ([1, 2, 3, 4, 5, 6, 7, 8] as $exifTag) {
        $width = 320;
        $height = $orientation === 'Landscape' ? 240 : 427;

        if ($exifTag === 5 || $exifTag === 7) {
            // Swap input width and height when rotating by 90 or 270 degrees
            list($width, $height) = [$height, $width];
        }

        // Thumbnail options
        $thumbnailOptions = [
            'auto_rotate' => true,
            'linear' => false,
            'height' => $height,
            'size' => Size::DOWN
        ];

        $image = Image::thumbnail(
            __DIR__ . '/input/' . $orientation . '_' . $exifTag . '.jpg',
            $width,
            $thumbnailOptions
        );

        $rotate = 0;
        $flip = false;
        $flop = false;

        // `vips_autorot` doesn't support the various mirror modes, so we take care of it.
        switch ($exifTag) {
            case 2: // flop 1
                $flop = true;
                break;
            case 7: // flip 6
                $flip = true;
                $rotate = 90;
                break;
            case 4: // flop 3
                $flop = true;
                $rotate = 180;
                break;
            case 5: // flip 8
                $flip = true;
                $rotate = 270;
                break;
        }

        // Remove EXIF Orientation from image, if mirroring is required.
        if ($flip || $flop) {
            $image->remove(VIPS_META_ORIENTATION);
        }

        // Rotate if required.
        if ($rotate !== 0) {
            // Need to copy to memory, we have to stay seq.
            $image = $image->copyMemory()->rot('d' . $rotate);
        }

        // Flip (mirror about Y axis) if required.
        if ($flip) {
            $image = $image->flipver();
        }

        // Flop (mirror about X axis) if required.
        if ($flop) {
            $image = $image->fliphor();
        }

        $image->writeToFile(__DIR__ . '/output/' . $orientation . '_' . $exifTag . '-out.jpg');
    }
}